# 📦 pco「pip current origin」

## 安装

```bash
pip install pipco
```

## 查看帮助

```bash
pco help
```


## 知识星球

![](https://bornforthis.cn/zsxq.jpg)

## 个人二维码

![](https://raw.githubusercontent.com/AndersonHJB/pipco/main/images/img.png)